function dPqij=Pmatrixderivs(Q,i,j,t);
%partial derivatives of a P matrix with respect to entry i,j of the Q matrix
%SYNTAX
%dPqij=Pmatrixderivs(Q,i,j,t);
%INPUTS
%Q is the Q matrix (continuous time rate matrix for a Markov chain)
%i and j are the indices of the element of q with respect to which we want
%partial derivatives of P(t)=expm(Q*t)
%t is the time (optional: default 1)
%OUTPUTS
%dPqij is a matrix of partial derivatives of P=expm(Q) with respect to q_ij
%NOTES
%checked for a 2 x 2 case where we have analytical derivatives
%assumes the Q matrix is diagonalizable, which will be true if it has all
%distinct eigenvalues
%SOURCE
%Schadt, E. and Lange, K. (2002).  Codon and rate variation models in
%molecular phylogeny.  Molecular Biology and Evolution 19:1534-1549.
%Derivation described more helpfully in Najfeld, I. and Havel, T. F. (1995) Derivatives of the
%matrix exponential and their computation.  Advances in Applied Mathematics
%16:321-375.

if nargin<4
    t=1;
end;
n=size(Q,1);
dQ=zeros(n);
dQ(i,j)=1;
dQ(j,j)=-1;
[S,D]=eig(Q);%assume eigenvalues are distinct
Sinv=inv(S);%is there are better way than inverting S explicitly?

%build F
d=diag(D);
dd=d(:,ones(1,n));
ed=exp(dd*t);%elementwise
F=(ed-ed')./(dd-dd');
F(logical(eye(n)))=t*exp(d*t);

%Hadamard product of F with Sinv*dQ*S
hp=F.*(Sinv*dQ*S);

dPqij=S*hp*Sinv;

