function [dwn,dwnscale]=Pstat_partialderiv(P,i,j,n);
%calculate partial derivative of nth right eigenvector of a Markov chain with
%respect to element i,j of the P matrix
%assume that eigenvectors
%are in descending order of eigenvalue
%SYNTAX
%[dwn,dwnscale]=Pstat_partialderiv(Q,i,j,n);
%INPUTS
%P is the P matrix, where p_ij is the probability of transition from state j to
%state i in one unit of time (ecology convention)
%i,j is the index of the element for which we want the derivative
%n is the index of the eigenvector for which we want the derivative
%OUTPUTS
%dwn is a vector of partial derivatives of the eigenvector corresponding to the
%nth eigenvalue with respect to element i,j of P 
%dwnscale is a vector of partial derivatives of the eigenvector corresponding to
%the nth eigenvalue with respect to element i,j of P, maintaining the sum of the
%eigenvector at 1.
%NOTES
%suspect lots of simplification is possible
%USES
%sorted_eigs.m

s=size(P,1);

%get the eigenvalues and eigenvectors
[lambda,W,V]=sorted_eigs(P);

%get complex conjugates of left eigenvectors
%NOTE FOR LATER: this means we really just have inv(W)
Vcc=conj(V);

%do the summation
dwn=0;
for m=2:s
    dwn=dwn+(Vcc(m,i)-Vcc(m,j))/(lambda(n)-lambda(m))*W(:,m);
end;

dwn=W(j,n)*dwn;

%get the scaled version: IS THIS ALWAYS THE SAME AS UNSCALED FOR A Q MATRIX?
dwnscale=dwn-W(:,n)*sum(dwn);