function [dwn,dwnscale]=Qstat_deriv(Q,i,j,n);
%calculate derivative of nth eigenvector of a Markov chain with
%respect to element i,j of the Q matrix
%assume that the elements in a column are independent, so compensation
%occurs by changing the diagonal element j,j only, and that eigenvectors
%are in descending order of eigenvalue
%SYNTAX
%[dwn,dwnscale]=Qstat_deriv(Q,i,j,n);
%INPUTS
%Q is the Q matrix, where q_ij is the rate of transition from state j to
%state i (ecology convention)
%i,j is the index of the element for which we want the derivative
%n is the index of the eigenvector for which we want the derivative
%OUTPUTS
%dwn is a vector of derivatives of the eigenvector corresponding to the
%nth eigenvalue with respect to element i,j of Q (accounting for the
%compensating change in element j,j)
%dwnscale is a vector of derivatives of the eigenvector corresponding to
%the nth eigenvalue with respect to element i,j of Q, accounting for the
%compensating change in element j,j and for maintaining the sum of the
%eigenvector at 1.
%NOTES
%suspect lots of simplification is possible
%I think dwnscale is always the same as dwscale for a Q matrix
%USES
%sorted_eigs.m

s=size(Q,1);

%get the eigenvalues and eigenvectors
[lambda,W,V]=sorted_eigs(Q);

%get complex conjugates of left eigenvectors
%NOTE FOR LATER: this means we really just have inv(W)
Vcc=conj(V);

%do the summation
dwn=0;
for m=2:s
    dwn=dwn+(Vcc(m,i)-Vcc(m,j))/(lambda(n)-lambda(m))*W(:,m);
end;

dwn=W(j,n)*dwn;

%get the scaled version: IS THIS ALWAYS THE SAME AS UNSCALED FOR A Q MATRIX?
dwnscale=dwn-W(:,n)*sum(dwn);