function [Vc,dPqij]=invert_Pmatrixderivs(Q,V,t);
%find changes in a Q matrix needed to achieve a specified direction of
%change in a P matrix
%SYNTAX
%[Vc,dPqij]=invert_Pmatrixderivs(Q,V,t);
%INPUTS
%Q is the Q matrix (continuous time rate matrix for a Markov chain)
%V is a direction of change in corresponding P matrix
%t is the time (optional: default 1)
%OUTPUTS
%Vc is a matrix of directional changes in Q that corresponds to the
%specified change V in P
%dPqij is a check that we really got the right answer: after finding Vc, we
%do the transformation in the forward direction on Vc.  We should get
%dPij=V
%NOTES
%assumes the Q matrix is diagonalizable, which will be true if it has all
%distinct eigenvalues

if nargin<3
    t=1;
end;
n=size(Q,1);
[S,D]=eig(Q);%assume eigenvalues are distinct
Sinv=inv(S);%is there are better way than inverting S explicitly?

%build F
d=diag(D);
dd=d(:,ones(1,n));
ed=exp(dd*t);%elementwise
F=(ed-ed')./(dd-dd');
F(logical(eye(n)))=t*exp(d*t);

%inverse Hadamard product of F with Sinv*dQ*S
ihp=(Sinv*V*S)./F;
Vc=S*ihp*Sinv;

%check it works...
%build F

%Hadamard product of F with Sinv*dQ*S
hp=F.*(Sinv*Vc*S);

dPqij=S*hp*Sinv;